package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppletPetType;

/**
 * 个人宠物类型Service接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface IAppletPetTypeService 
{
    /**
     * 查询个人宠物类型
     * 
     * @param id 个人宠物类型主键
     * @return 个人宠物类型
     */
    public AppletPetType selectAppletPetTypeById(Long id);

    /**
     * 查询个人宠物类型列表
     * 
     * @param appletPetType 个人宠物类型
     * @return 个人宠物类型集合
     */
    public List<AppletPetType> selectAppletPetTypeList(AppletPetType appletPetType);

    /**
     * 新增个人宠物类型
     * 
     * @param appletPetType 个人宠物类型
     * @return 结果
     */
    public int insertAppletPetType(AppletPetType appletPetType);

    /**
     * 修改个人宠物类型
     * 
     * @param appletPetType 个人宠物类型
     * @return 结果
     */
    public int updateAppletPetType(AppletPetType appletPetType);

    /**
     * 批量删除个人宠物类型
     * 
     * @param ids 需要删除的个人宠物类型主键集合
     * @return 结果
     */
    public int deleteAppletPetTypeByIds(Long[] ids);

    /**
     * 删除个人宠物类型信息
     * 
     * @param id 个人宠物类型主键
     * @return 结果
     */
    public int deleteAppletPetTypeById(Long id);
}
